#
# spec file for package flameshot
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           flameshot
Version:        0.8.5
Release:        bp153.1.1
Summary:        Screenshot software
License:        GPL-3.0-only
Group:          Productivity/Graphics/Other
URL:            https://github.com/lupoDharkael/flameshot#flameshot
#Git-Clone:     https://github.com/flameshot-org/flameshot.git
Source0:        https://github.com/lupoDharkael/flameshot/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqt5-linguist-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core) >= 5
BuildRequires:  pkgconfig(Qt5DBus) >= 5
BuildRequires:  pkgconfig(Qt5Gui) >= 5
BuildRequires:  pkgconfig(Qt5Network) >= 5
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Widgets) >= 5

%description
A program to capture screenshots.
It includes CLI options as well as a UI for capturing and annotating screenshots.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          Productivity/Graphics/Other
Requires:       %{name} = %{version}
Requires:       bash-completion
Supplements:    (flameshot and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash completion script for flameshot's CLI.

%package zsh-completion
Summary:        ZSH completion for %{name}
Group:          Productivity/Networking/Security
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
zsh shell completions for %{name}.

%prep
%setup -q

%build
%cmake
%make_jobs

%install
%cmake_install
install -d %{buildroot}/%{_sysconfdir}/zsh_completion.d
mv %{buildroot}%{_datadir}/zsh/site-functions/_flameshot %{buildroot}%{_sysconfdir}/zsh_completion.d/%{name}
%suse_update_desktop_file -r org.flameshot.Flameshot Utility X-SuSE-DesktopUtility
%fdupes %{buildroot}%{_datadir}/icons/hicolor

%files
%{_bindir}/%{name}
%{_datadir}/%{name}
%{_datadir}/applications/org.flameshot.Flameshot.desktop
%{_datadir}/dbus-1/interfaces/org.flameshot.Flameshot.xml
%{_datadir}/dbus-1/services/org.flameshot.Flameshot.service
%{_datadir}/icons/hicolor/*/apps/*.png
%{_datadir}/icons/hicolor/scalable/apps/*.svg
%{_datadir}/metainfo/org.flameshot.Flameshot.metainfo.xml

%files bash-completion
%{_datadir}/bash-completion/completions/%{name}

%files zsh-completion
%dir %{_sysconfdir}/zsh_completion.d
%config %{_sysconfdir}/zsh_completion.d/%{name}

%changelog
* Fri Oct 16 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.5
  * Fixed Icon Regression
* Sun Oct 11 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.4
  * Renamed assets to match DBUS name for flathub support.
  * Fixed issue where theme was not applied to widgets.
  * Fixed issue where pixelate tool did not properly apply pixel
    size and was not symmetric horizontally and vertically.
  * Fixed visual artifact in pin to desktop in appimage release.
  * Fixed issue where CTRL + S did not save active text in text
    tool.
  * Imgur tool now opens in the center of the screen.
  * Translation Updates
    + Brazilian Portuguese
    + German
    + Korean
    + Basque
* Tue Sep 29 2020 Martin Hauke <mardnh@gmx.de>
- Update to versin 0.8.3
  * Small bug fixes
* Thu Sep 24 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.1
  * Auto contrast on circle counter
* Tue Sep 22 2020 Martin Hauke <mardnh@gmx.de>
- Update to version 0.8.0
  New Features
  * Fix capture after pressing ctrl + S during textarea input
  * Add translations
  * Allow enter key to copy image to clipboard
  * side panel: Add thickness slider
  * Add support for saving as JPG and BMP files.
  * Allow 45 degree adjustment for some tools
  * Add a basic launcher panel.
  * Add option to auto copy URL after upload
  * Add a circle counter tool.
  * Replace the blur tool with pixelate tool.
  * Convert buildsystem from QMake to CMake.
  Fixes
  * Exit non-zero when aborting with --raw.
  * Enable Pin and Text tool by default.
  * Fix the problem that moving or resizing does not affect
    screenshot.
  * Fix problem with re-enabling disabled tray icon.
  * Fix compilation problem against Qt 5.15.
- Drop not longer needed patches:
  * 0001-Fix-build-with-Qt-5.15.patch
  * 0001-utils-confighandler.cpp-Enable-Pin-and-Text-tool-by-.patch
  * desktop-files.patch
- Introduce zsh-completion subpackage
* Fri Jun  5 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to fix build with Qt 5.15:
  * 0001-Fix-build-with-Qt-5.15.patch
* Mon Mar  9 2020 Martin Hauke <mardnh@gmx.de>
- Supplement against bash-completion, not bash
* Sun Apr  7 2019 Martin Hauke <mardnh@gmx.de>
- Add patch:
  * 0001-utils-confighandler.cpp-Enable-Pin-and-Text-tool-by-.patch
    Enables Pin and Text tool by default.
* Tue Aug 28 2018 aloisio@gmx.com
- Update to version 0.6.0
  Features:
  * Allow systray customization with themes. Use
    "flameshot-tray" as the name of the icon.
  * Unification of the desktop file with actions.
  * Notification when screenshots are saved in the clipboard.
  * Use datetime as default name for pics.
  * Undo/Redo with Ctrl+z and Ctrl+Shift+z.
  * Add "Take Screenshot" option as menu item in the systray.
  * Add Side-Panel (open it with Space).
  * Add autostart to config flags.
  * Add Pin tool.
  * Filename: replace colons with dashes.
  * Add Text tool.
  * Delete Imgur image button after uploading it from the
    preview window.
  * Capture single screen:
    + flameshot screen (capture the screen containing the mouse)
    + flameshot screen -n 1 (capture the first screen).
  * Store settings colors in hexadecimal format.
  Fixes:
  * flameshot full -c shouldn't block the desktop.
  * Now you can overwrite exported configuration with the same
    name as a previous exports.
  * Fix flameshot --raw wait time with delay.
  * Fix negative selection geometry bug.
  * Improved hidpi support with some bugs fixed.
- Refreshed desktop-files.patch
* Sat Feb 24 2018 avindra@opensuse.org
- Bump to 0.5.1
  * Modal widgets doesn't prevent the start of a new capture
  * Better hidpi support
  * Tool buttons now don't go out of the screen
  * Use of native file dialog
  * Configurable opacity of the dark area outside the selection
  * Autostart app as a configuration option
  * Polish, french, georgian, chinese, turkish and rusian
    translations
  * Minor fixes
- rebase desktop-files.patch
* Thu Dec 28 2017 jengelh@inai.de
- Remove filler wording from description.
* Fri Dec 22 2017 avindra@opensuse.org
- Bump to 0.5.0
  * Features
  - Blur tool
  - Bash completion
  - Add --raw flag: prints the raw bytes of the png after the capture
  - Catalan translation
  - Preview draw size on mouse pointer after tool selection
  - App Launcher tool: choose an app to open the capture
  - Configuration import, export and reset
  - Experimental Wayland support (Plasma & Gnome)
  - Debian package configuration
  * Accessibility
  - Capture selection resizable from any edge
  * Fixes
  - App version shown properly
  - cli wont break if you prepend gui, full and config arguments
    with a dash
  - Fix rare crash when creating a selection during a graphical
    capture
- Build cleanup:
  * Remove unneeded service file
  * Use Qt macros for building and installing
  * Remove now unneeded .deskop file handling macros
- Package bash completions
* Sun Sep 17 2017 aavindraa@gmail.com
- Bump to 0.4.2 (hotfix release)
- hotfix: persistent configuration wasn't handled correctly for new
  users, failing to set a "initiated" status flag in the
  configuration. That is used to let the program know if a new
  process of Flameshot is the first launch of the program.
* Thu Aug 17 2017 aavindraa@gmail.com
- 0.4.0 release (https://github.com/lupoDharkael/flameshot/releases/tag/v0.4.0)
- lint .spec file
* Tue Aug 15 2017 aavindraa@gmail.com
- Package for the first time (with v0.3.0)
